SCUBA  [![Build Status](https://github.com/JonathonReinhart/scuba/actions/workflows/build-test.yml/badge.svg)](https://github.com/JonathonReinhart/scuba/actions/workflows/build-test.yml) [![codecov.io](https://codecov.io/github/JonathonReinhart/scuba/coverage.svg?branch=master)](https://codecov.io/github/JonathonReinhart/scuba?branch=master) [![PyPI](https://img.shields.io/pypi/v/scuba.svg)](https://pypi.python.org/pypi/scuba) [![Docs](https://readthedocs.org/projects/scuba/badge/?version=latest)](https://scuba.readthedocs.io/)
-----

Simple Container-Utilizing Build Apparatus

Scuba makes it easier to use Docker containers in everyday development. It is
intended to be used by developers with `make` or `scons`-based build systems,
where the entire build environment is encapsulated in a Docker container.

For more information, [Read the Docs](https://scuba.readthedocs.io/).

## License

This software is released under the [MIT License](https://opensource.org/licenses/MIT).
